==> wizcloud-api-1.0.2.tgz: package/examples/IndexApiExample.js <==
////////////////////////////////////////////////////////////basic required code 
//Must to configure private data on apiConfig.js file
const wizlib = require("../wizApiExternalLib.js");
//var express = require("express");
//var router = express.Router();
var fs   = require('fs');
var myObjData;
			try{
				myObjData=JSON.parse(fs.readFileSync('../apiConfig.js'));
			}catch(e){ //no config file take from fs
				console.log(e);				
      }
var myDBname=myObjData.WizcloudApiDBName;
wizlib.init(myObjData.WizcloudApiPrivateKey, myObjData.WizcloudApiServer);
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Jason data example- client responsibility

let trans = [
	{
		AccountKey: "tutu12345",
		FullName: "tutu123",
		SortGroup: "258",
		CostCode: "22",
		AssignKey:"777",
		DeductionPrc:11,
		DeductionValid:"28/02/2019"
		
	},
	{
		
		AccountKey: "8888123664",
		FullName: "8888 name new",
		SortGroup: "1234",
		CostCode: "1"
	}
];

let trans1 = [
	{
		ItemKey: "parit23",
		ItemName: "parit23parit23parit23parit23",
		SortGroup: "123",
		Price: "123",
		IntrItem:"1",
		BarCode:"1234688999999",
		DatF1:"28/02/2019"
		
	},
	{
		ItemKey: "ppp888656565656565",
		ItemName: "parit2 name",
		SortGroup: "258",
		Price: "22"
	}
];

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Api methods
async function importIndexRecords(){
	let apiRes = await wizlib.importIndexRecords(myDBname, { myindex:'acc',insertnew:true, rows: trans });
	console.log(apiRes)
}

importIndexRecords();

/*
router.get("/acc", async function(req, res) {
	let apiRes = await wizlib.importIndexRecords(myDBname, { myindex:'acc',insertnew:true, rows: trans });
	res.json(apiRes);
});

router.get("/itm", async function(req, res) {
	let apiRes = await wizlib.importIndexRecords(myDBname, { myindex:'itm',insertnew:true, rows: trans1});
	res.json(apiRes);
});

module.exports = router;
*/

==> wizcloud-api-1.0.15.tgz: package/examples/IndexApiExample.js <==
////////////////////////////////////////////////////////////basic required code 
//Must to configure private data on apiConfig.js file
const wizlib = require("wizcloud-api");
var fs   = require('fs');
var myObjData;
			try{
				myObjData=JSON.parse(fs.readFileSync('apiConfig.js'));
			}catch(e){ //no config file take from fs
				console.log(e);				
      }
var myDBname=myObjData.WizcloudApiDBName;
wizlib.init(myObjData.WizcloudApiPrivateKey, myObjData.WizcloudApiServer);
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Jason data example- client responsibility

let trans = [
	{
		AccountKey: "tutu12345",
		FullName: "tutu123",
		SortGroup: "258",
		CostCode: "22",
		AssignKey:"777",
		DeductionPrc:11,
		DeductionValid:"28/02/2019"
		
	},
	{
		
		AccountKey: "8888123664",
		FullName: "8888 name new",
		SortGroup: "1234",
		CostCode: "1"
	}
];

let trans1 = [
	{
		ItemKey: "parit23",
		ItemName: "parit23parit23parit23parit23",
		SortGroup: "123",
		Price: "123",
		IntrItem:"1",
		BarCode:"1234688999999",
		DatF1:"28/02/2019"
		
	},
	{
		ItemKey: "ppp888656565656565",
		ItemName: "parit2 name",
		SortGroup: "258",
		Price: "22"
	}
];

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Api methods
async function importIndexRecords(){
	let apiRes = await wizlib.importIndexRecords(myDBname, { myindex:'acc',insertnew:true, rows: trans });
	console.log(apiRes);
	fs.writeFile('myApiRes.txt', JSON.stringify(apiRes), (err) => {
    if (err) throw err;
		console.log('See resaults in myApiRes.txt');
	});
}

importIndexRecords();
